<?php
namespace PLA\Util;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class Util {
	
    protected $crudService;
    protected $newCode;
    protected $environment;
    protected $dataSourceManager;
    protected $connection;
    
    const TABLE_LISTA = "LISTA";

	public function __construct($crudService, $newCode, $environment, $dataSourceManager, $connection) {
        $this->crudService = $crudService;
        $this->newCode = $newCode;
        $this->environment = $environment;
		$this->dataSourceManager = $dataSourceManager;
		$this->connection = $connection;
	}

    public function validateDuplicatedRecords($row, $dataSourceName, $columns) {
        $conditions = array();
        foreach ($columns as $column) {
            array_push($conditions, array(
                "columnName" => $column,
                "operator"   => '=',
                "value"      => $row[$column]
            ));
        }
        $dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions);

        if (!empty($dataSet->getRows())) {
            throw new \Exception("registerExists", 1);
        }
    }

    public function insertLista($cdlistaArray) {
        $dataSourceName = strtolower(self::TABLE_LISTA);
        $nrlista = $this->newCode->getCodeByTableName(self::TABLE_LISTA, $this->environment->getNrOrg());
        $sql = "INSERT INTO " . self::TABLE_LISTA . " (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        
        foreach ($cdlistaArray as $cdlista) {
            $params = array(
                "NRLISTA" => $nrlista,
                "CDLISTA" => $cdlista
            );
            $query = $this->connection->prepare($sql);
    	    $query->execute($params);
        }
        
        return $nrlista;
    }

    //cria lista de valores recebendo string como parametro
    public function criarListaValores($valores){
        if(strlen($valores) <= 4000){
            return $valores;
        }else{
            $lista = explode('_',$valores);
            try{
                $nrlista = $this->insertLista($lista);
                return "_NRLISTA=".$nrlista;
            } catch(\Exception $e){
                throw $e;
            }
        }
    }
    
    public function deleteLista($nrlista) {
        $sql = "DELETE FROM LISTA WHERE NRLISTA = :NRLISTA";
        $params = array(
            "NRLISTA" => $nrlista
        );
        $query = $this->connection->prepare($sql);
    	$query->execute($params);
    }

    public function deleteListaErros($nrlista) {
        $sql = "DELETE FROM LISTAERROS WHERE NRLISTA = :NRLISTA";
        $params = array(
            "NRLISTA" => $nrlista
        );
        $query = $this->connection->prepare($sql);
    	$query->execute($params);
    }

    public function apagarListaValores($valores){
        try{
            if(substr($valores, 0,9) == "_NRLISTA="){
                $nrlista = substr($valores, 9);
                $this->deleteLista($nrlista);
            }
        } catch(\Exception $e){
            throw $e;
        }
    }

    public function deleteConsplan($nrconsplan, $cdfilicpla) {
        $sql = "DELETE FROM CONSPLAN WHERE NRCONSPLAN = :NRCONSPLAN AND (CDFILICPLA = :CDFILICPLA OR :CDFILICPLA = NULL) AND NRORG = :NRORG";
        $params = array(
            "NRCONSPLAN" => $nrconsplan,
            "CDFILICPLA" => $cdfilicpla,
            "NRORG"      => $this->environment->getNrOrg()
        );
        $query = $this->connection->prepare($sql);
    	$query->execute($params);
    }

    public static function converter($message){
		$messageUpper 	= strtoupper($message);
		$codeStart	 	= strpos($messageUpper, "_MSGSTA_");
		$codeEnd		= strpos($messageUpper, "_MSGEND_");
		
		if ($codeStart !== FALSE && $codeEnd !== FALSE){
			$msgStart = $codeStart + strlen("_MSGSTA_");
			$msgEnd = $codeEnd - $msgStart;

	        $paramstring = substr($message, $msgStart, $msgEnd);
	        $params = explode("$$", $paramstring);
	        
            $mensagem = array_shift($params);
	        
	        $resultado = array("MSGCODE"=>$mensagem);
	        $resultado['PARAMS'] = array();
	        
	        if(sizeof($params) > 0){
	            $parametros = array();
	            foreach ($params as $index => $value) {
	                 $parametros['PARAM'.$index] = $value;
	            }
	            $resultado['PARAMS'] = $parametros;
	        }
	        
	        return $resultado;
		}
		return $message;
	}

	public function getMessageErrorList($nrlista){
	    $sql = 'SELECT DISTINCT DSERRO FROM LISTAERROS WHERE NRLISTA = :NRLISTA ORDER BY DSERRO';
	    $params = array(
	        'NRLISTA'  => $nrlista
	    );
	    $pstmt = $this->connection->prepare($sql);
	    $pstmt->execute($params);
	    return $pstmt->fetchAll(\PDO::FETCH_ASSOC);
	}
}